[hobbit] default dely value for hobbit-mailack

Henrik Stoerner henrik at hswn.dk
Sat Jun 25 08:21:00 CEST 2005


On Fri, Jun 24, 2005 at 04:19:09PM -0400, Sue Bauer-Lee wrote:
> Maybe I missed something somewhere but the man page hobbit-mailack says the
> default delay value = 1 hour (60m). Whenever users use email ack a Hobbit 
> alert message, the default delay appears to be 30 minutoes.

Oops, you're right.

I've changed the code so that it is 60 minutes, as the man-page says.
Patch attached.

Regards,
Henrik

-------------- next part --------------
--- hobbitd/hobbit-mailack.c	2005/05/07 09:24:20	1.8
+++ hobbitd/hobbit-mailack.c	2005/06/25 06:20:08
@@ -12,7 +12,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: hobbit-mailack.c,v 1.8 2005/05/07 09:24:20 henrik Exp $";
+static char rcsid[] = "$Id: hobbit-mailack.c,v 1.9 2005/06/25 06:20:00 henrik Exp $";
 
 #include <ctype.h>
 #include <stdio.h>
@@ -141,7 +141,7 @@
 	}
 
 	/* Setup the acknowledge message */
-	if (duration == 0) duration = 30;	/* Default: Ack for 30 minutes */
+	if (duration == 0) duration = 60;	/* Default: Ack for 60 minutes */
 	p = buf;
 	p += sprintf(p, "hobbitdack %s %d %s", cookie, duration, firsttxtline);
 	if (fromline) {


More information about the Xymon mailing list